=================
django-ignorebots
=================

.. image:: https://img.shields.io/pypi/v/django-ignorebots.svg
     :target: https://pypi.python.org/pypi/django-ignorebots

.. image:: https://img.shields.io/travis/acordiner/django-ignorebots.svg
     :target: https://travis-ci.org/acordiner/django-ignorebots

.. image:: https://readthedocs.org/projects/django-ignorebots/badge/?version=latest
     :target: https://django-ignorebots.readthedocs.io/en/latest/?badge=latest
     :alt: Documentation Status

.. image:: https://pyup.io/repos/github/acordiner/django-ignorebots/shield.svg
     :target: https://pyup.io/repos/github/acordiner/django-ignorebots/
     :alt: Updates

The Django-provided ``BrokenLinkEmailsMiddleware`` is a handy way to be notified
whenever a user hits a 404 error on your website. The problem is, once you
enable it, you tend to get spammed by notifications due to bots scanning you
website repeatedly hitting 404 errors. This can include search engine crawlers,
exploit scanners, and even browsers.

This simple Django plug-in helps you to filter these out so that you are only
notified when a real user hits a 404 error.

Ignore all the bots!

*Documentation coming soon.*
